from setuptools import setup, find_packages

setup(
    name="tavo",
    version="0.1.3",
    description="Bino full-stack framework CLI - Python backend + Rust/SWC React SSR",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Hallel",
    author_email="admin@cyberwizdev.com.ng",
    license="MIT",
    packages=find_packages(include=["tavo", "tavo.*"]),
    python_requires=">=3.9",
    install_requires=[
        "anyio==4.10.0",
        "build==1.3.0",
        "certifi==2025.8.3",
        "charset-normalizer==3.4.3",
        "click==8.2.1",
        "colorama==0.4.6",
        "docutils==0.22",
        "id==1.5.0",
        "idna==3.10",
        "jaraco.classes==3.4.0",
        "jaraco.context==6.0.1",
        "jaraco.functools==4.3.0",
        "keyring==25.6.0",
        "markdown-it-py==4.0.0",
        "mdurl==0.1.2",
        "more-itertools==10.7.0",
        "nh3==0.3.0",
        "packaging==25.0",
        "Pygments==2.19.2",
        "pyproject_hooks==1.2.0",
        "python-dotenv==1.1.1",
        "pywin32-ctypes==0.2.3; sys_platform == 'win32'",
        "readme_renderer==44.0",
        "requests==2.32.5",
        "requests-toolbelt==1.0.0",
        "rfc3986==2.0.0",
        "rich==14.1.0",
        "semantic-version==2.10.0",
        "setuptools-rust==1.11.1",
        "shellingham==1.5.4",
        "sniffio==1.3.1",
        "starlette==0.47.3",
        "twine==6.1.0",
        "typer==0.16.1",
        "typing_extensions==4.15.0",
        "urllib3==2.5.0",
        "watchfiles==1.1.0",
        "websockets==15.0.1",
    ],
    entry_points={
        "console_scripts": [
            "tavo = tavo.cli.main:app",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
